Module parallelism

Module parallelism 

Useful utilities for discovering the desired level of parallelism

Functions

get_available_parallelism
Estimates the degree of parallelism the program should use, caching the result after the first call.