Module tree

Module tree 

Shared traversal and rendering utilities for named trees.

Structs

DepthContext
Tree traversal context that records only the current depth.
IndentedFormatter
Access to a formatter together with the indentation for detail lines.

Traits

TreeDisplayAdapter
Adapts a domain-specific node and traversal context to the shared tree renderers.
TreeDisplayContext
Traversal state updated as a tree renderer enters and leaves a node’s children.
TreeDisplayExtractor
Contributes one composable dimension of information to tree nodes.

Functions

write_branch_tree
Render a tree using Unicode branch connectors.
write_indented_tree
Render a named tree using two-space indentation.