Shared traversal and rendering utilities for named trees.
Structs
- Depth
Context - Tree traversal context that records only the current depth.
- Indented
Formatter - Access to a formatter together with the indentation for detail lines.
Traits
- Tree
Display Adapter - Adapts a domain-specific node and traversal context to the shared tree renderers.
- Tree
Display Context - Traversal state updated as a tree renderer enters and leaves a node’s children.
- Tree
Display Extractor - Contributes one composable dimension of information to tree nodes.
Functions
- write_
branch_ tree - Render a tree using Unicode branch connectors.
- write_
indented_ tree - Render a named tree using two-space indentation.